Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon MemoryDB.

Actions, resources, and condition keys for Amazon MemoryDB - Service Authorization Reference

# Actions, resources, and condition keys for Amazon MemoryDB

Amazon MemoryDB (service prefix: `memorydb` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon MemoryDB
- Resource types defined by Amazon MemoryDB
- Condition keys for Amazon MemoryDB

## Actions defined by Amazon MemoryDB

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Note

When you create a MemoryDB for Redis policy in IAM you must use the "*" wildcard character for the Resource block. For information about using the following MemoryDB for Redis API actions in an IAM policy, see MemoryDB Actions and IAM .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BatchUpdateClusters | Grants permissions to apply service updates | Write | cluster* |  | ec2:CreateNetworkInterface ec2:DeleteNetworkInterface ec2:DescribeNetworkInterfaces ec2:DescribeSubnets ec2:DescribeVpcs s3:GetObject
| aws:ResourceTag/${TagKey} |
CopySnapshot | Grants permissions to make a copy of an existing snapshot | Write | snapshot* |  | memorydb:TagResource s3:DeleteObject s3:GetBucketAcl s3:PutObject
| aws:ResourceTag/${TagKey} aws:RequestTag/${TagKey} aws:TagKeys |
CreateAcl | Grants permissions to create a new access control list | Write | user* |  | memorydb:TagResource
| aws:ResourceTag/${TagKey} aws:RequestTag/${TagKey} aws:TagKeys |
CreateCluster | Grants permissions to create a cluster | Write | acl* |  | ec2:CreateNetworkInterface ec2:DeleteNetworkInterface ec2:DescribeNetworkInterfaces ec2:DescribeSubnets ec2:DescribeVpcs memorydb:TagResource s3:GetObject
parametergroup* |  |
subnetgroup* |  |
snapshot |  |
| aws:ResourceTag/${TagKey} aws:RequestTag/${TagKey} aws:TagKeys |
CreateParameterGroup | Grants permissions to create a new parameter group | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | memorydb:TagResource
CreateSnapshot | Grants permissions to create a backup of a cluster at the current point in time | Write | cluster* |  | memorydb:TagResource s3:DeleteObject s3:GetBucketAcl s3:PutObject
| aws:ResourceTag/${TagKey} aws:RequestTag/${TagKey} aws:TagKeys |
CreateSubnetGroup | Grants permissions to create a new subnet group | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | memorydb:TagResource
CreateUser | Grants permissions to create a new user | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | memorydb:TagResource
DeleteAcl | Grants permissions to delete an access control list | Write | acl* |  |
| aws:ResourceTag/${TagKey} |
DeleteCluster | Grants permissions to delete a previously provisioned cluster | Write | cluster* |  | ec2:CreateNetworkInterface ec2:DeleteNetworkInterface ec2:DescribeNetworkInterfaces ec2:DescribeSubnets ec2:DescribeVpcs
snapshot |  |
| aws:ResourceTag/${TagKey} |
DeleteParameterGroup | Grants permissions to delete a parameter group | Write | parametergroup* |  |
| aws:ResourceTag/${TagKey} |
DeleteSnapshot | Grants permissions to delete a snapshot | Write | snapshot* |  |
| aws:ResourceTag/${TagKey} |
DeleteSubnetGroup | Grants permissions to delete a subnet group | Write | subnetgroup* |  | ec2:CreateNetworkInterface ec2:DeleteNetworkInterface ec2:DescribeNetworkInterfaces ec2:DescribeSubnets ec2:DescribeVpcs
| aws:ResourceTag/${TagKey} |
DeleteUser | Grants permissions to delete a user | Write | user* |  |
| aws:ResourceTag/${TagKey} |
DescribeAcls | Grants permissions to retrieve information about access control lists | Read | acl* |  |
| aws:ResourceTag/${TagKey} |
DescribeClusters | Grants permissions to retrieve information about all provisioned clusters if no cluster identifier is specified, or about a specific cluster if a cluster identifier is supplied | Read | cluster* |  |
| aws:ResourceTag/${TagKey} |
DescribeEngineVersions | Grants permissions to list of the available engines and their versions | Read |  |  |
DescribeEvents | Grants permissions to retrieve events related to clusters, subnet groups, and parameter groups | Read |  |  |
DescribeParameterGroups | Grants permissions to retrieve information about parameter groups | Read | parametergroup* |  |
| aws:ResourceTag/${TagKey} |
DescribeParameters | Grants permissions to retrieve a detailed parameter list for a particular parameter group | Read | parametergroup* |  |
| aws:ResourceTag/${TagKey} |
DescribeServiceUpdates | Grants permissions to retrieve details of the service updates | Read |  |  |
DescribeSnapshots | Grants permissions to retrieve information about cluster snapshots | Read | snapshot* |  |
| aws:ResourceTag/${TagKey} |
DescribeSubnetGroups | Grants permissions to retrieve a list of subnet group | Read | subnetgroup* |  |
| aws:ResourceTag/${TagKey} |
DescribeUsers | Grants permissions to retrieve information about users | Read | user* |  |
| aws:ResourceTag/${TagKey} |
FailoverShard | Grants permissions to test automatic failover on a specified shard in a cluster | Write | cluster* |  | ec2:CreateNetworkInterface ec2:DeleteNetworkInterface ec2:DescribeNetworkInterfaces ec2:DescribeSubnets ec2:DescribeVpcs
| aws:ResourceTag/${TagKey} |
ListNodeTypeUpdates | Grants permissions to list available node type updates | Read | cluster* |  |
| aws:ResourceTag/${TagKey} |
ListTags | Grants permissions to list cost allocation tags | Read | acl |  |
cluster |  |
parametergroup |  |
snapshot |  |
subnetgroup |  |
user |  |
| aws:ResourceTag/${TagKey} |
ResetParameterGroup | Grants permissions to modify the parameters of a parameter group to the engine or system default value | Write | parametergroup* |  |
| aws:ResourceTag/${TagKey} |
TagResource | Grants permissions to add up to 10 cost allocation tags to the named resource | Tagging | acl |  |
cluster |  |
parametergroup |  |
snapshot |  |
subnetgroup |  |
user |  |
| aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} |
UntagResource | Grants permissions to remove the tags identified by the TagKeys list from a resource | Tagging | acl |  |
cluster |  |
parametergroup |  |
snapshot |  |
subnetgroup |  |
user |  |
| aws:TagKeys aws:ResourceTag/${TagKey} |
UpdateAcl | Grants permissions to update an access control list | Write | acl* |  |
user* |  |
| aws:ResourceTag/${TagKey} |
UpdateCluster | Grants permissions to update the settings for a cluster | Write | cluster* |  | ec2:CreateNetworkInterface ec2:DeleteNetworkInterface ec2:DescribeNetworkInterfaces ec2:DescribeSubnets ec2:DescribeVpcs
acl |  |
parametergroup |  |
| aws:ResourceTag/${TagKey} |
UpdateParameterGroup | Grants permissions to update parameters in a parameter group | Write | parametergroup* |  |
| aws:ResourceTag/${TagKey} |
UpdateSubnetGroup | Grants permissions to update a subnet group | Write | subnetgroup* |  |
| aws:ResourceTag/${TagKey} |
UpdateUser | Grants permissions to update a user | Write | user* |  |
| aws:ResourceTag/${TagKey} |

## Resource types defined by Amazon MemoryDB

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
parametergroup | `arn:$ { Partition}:memorydb:$ { Region}:$ { Account}:parametergroup/$ { ParameterGroupName}` | aws:ResourceTag/${TagKey}
subnetgroup | `arn:$ { Partition}:memorydb:$ { Region}:$ { Account}:subnetgroup/$ { SubnetGroupName}` | aws:ResourceTag/${TagKey}
cluster | `arn:$ { Partition}:memorydb:$ { Region}:$ { Account}:cluster/$ { ClusterName}` | aws:ResourceTag/${TagKey}
snapshot | `arn:$ { Partition}:memorydb:$ { Region}:$ { Account}:snapshot/$ { SnapshotName}` | aws:ResourceTag/${TagKey}
user | `arn:$ { Partition}:memorydb:$ { Region}:$ { Account}:user/$ { UserName}` | aws:ResourceTag/${TagKey}
acl | `arn:$ { Partition}:memorydb:$ { Region}:$ { Account}:acl/$ { AclName}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon MemoryDB

Amazon MemoryDB defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on the tags associated with the resource | String
aws:TagKeys | Filters actions based on the tag keys that are passed in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.